==> kooPy-0.3.tar.gz: kooPy-0.3/setup.py <==
from distutils.core import setup
setup(
  name = 'kooPy',         # How you named your package folder (MyLib)
  packages = ['kooPy'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'KooPy: Koo for Python!',   # Give a short description about your library
  author = 'Nikhil',                   # Type in your name
  author_email = 'nikhil.bhamere@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/nick2580',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/nick2580/KooPy/archive/refs/tags/0.3.tar.gz',    # I explain this later on
  keywords = ['kooapp', 'koo', 'koopy'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> kooPy-0.4.tar.gz: kooPy-0.4/setup.py <==
from distutils.core import setup
setup(
  name = 'kooPy',         # How you named your package folder (MyLib)
  packages = ['kooPy'],   # Chose the same as "name"
  version = '0.4',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'KooPy: Koo for Python!',   # Give a short description about your library
  author = 'Nikhil',                   # Type in your name
  author_email = 'nikhil.bhamere@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/nick2580/KooPy',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/nick2580/KooPy/archive/refs/tags/0.4.tar.gz',    # I explain this later on
  keywords = ['kooapp', 'koo', 'koopy'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
